@@ -145,6 +145,13 @@ DEFAULT_STAFF_ASSESSMENT = {
     "required": False,
 }
 
+ACTIVE_STAFF_ASSESSMENT = {
+    "name": "staff-assessment",
+    "start": DEFAULT_START,
+    "due": DEFAULT_DUE,
+    "required": True,
+}
+
 DEFAULT_ASSESSMENT_MODULES = [
     DEFAULT_STUDENT_TRAINING,
     DEFAULT_PEER_ASSESSMENT,
@@ -158,3 +165,33 @@ DEFAULT_EDITOR_ASSESSMENTS_ORDER = [
     "self-assessment",
     "staff-assessment",
 ]
+
+BLANK_ASSESSMENT_MODULES = []
+
+SELF_ASSESSMENT_MODULES = [
+    DEFAULT_STUDENT_TRAINING,
+    DEFAULT_SELF_ASSESSMENT,
+]
+
+PEER_ASSESSMENT_MODULES = [
+    DEFAULT_STUDENT_TRAINING,
+    DEFAULT_PEER_ASSESSMENT,
+]
+
+STAFF_ASSESSMENT_MODULES = [
+    DEFAULT_STUDENT_TRAINING,
+    ACTIVE_STAFF_ASSESSMENT,
+
+]
+
+SELF_TO_PEER_ASSESSMENT_MODULES = [
+    DEFAULT_STUDENT_TRAINING,
+    DEFAULT_SELF_ASSESSMENT,
+    DEFAULT_PEER_ASSESSMENT,
+]
+
+SELF_TO_STAFF_ASSESSMENT_MODULES = [
+    DEFAULT_STUDENT_TRAINING,
+    DEFAULT_SELF_ASSESSMENT,
+    ACTIVE_STAFF_ASSESSMENT,
+]
